<?php

/**
 * @package     EU e-Privacy Directive
 * @copyright   Copyright (C) 2009 - 2014 Michael Richey. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
defined('_JEXEC') or die;

class plgAjaxEprivacy extends JPlugin {

	public function onAjaxEprivacy() {
		$this->app = JFactory::getApplication();
		$this->input = $this->app->input;
		$method = $this->input->get('method', 'error');
		if(!method_exists($this,'_'.$method))
		{
			return $this->_error();
		}
		
		$userparams = JComponentHelper::getParams('com_users');
		$sysparams = $this->sysParams();
		$this->_defaultACL = (integer)$userparams->get('guest_usergroup', 1);
		$this->_cookieACL = (integer)$sysparams->get('cookieACL', $this->_defaultACL);		
		return json_encode($this->{'_' . $method}($sysparams)? : $this->error());
	}

	// exposed methods globally available are prefixed with a single underscore
	private function _error() {
		return false;
	}
	
	private function _accept($sysparams) {
		$this->app->setUserState('plg_system_eprivacy', true);	
		$config = JFactory::getConfig();
		$name = 'plg_system_eprivacy';
		$value = date('Y-m-d');
		$expires = time() + 60 * 60 * 24 * (int) $this->params->get('longtermcookieduration', 30);
		$path = strlen($config->get('cookie_path')) ? $config->get('cookie_path') : '/';
		$domain = strlen($config->get('cookie_domain')) ? $config->get('cookie_domain') : $this->input->server->get('HTTP_HOST');
		$this->input->cookie->set($name, $value, $expires, $path, $domain, false, false);
		if ($sysparams->get('logaccept', false))
		{
			$o = new stdClass();
			$o->ip = $this->input->server->get('REMOTE_ADDR');
			$o->state = $this->input->get('country','not detected');
			$o->accepted = JFactory::getDate()->toSql();
			JFactory::getDbo()->insertObject('#__plg_system_eprivacy_log',$o);
		} else {
			$this->app->setUserState('plg_system_eprivacy_non_eu', false);
		}
		return true;
	}

	private function _decline() {
		header_remove('Set-Cookie');
		$app = JFactory::getApplication();
		$app->setUserState('plg_system_eprivacy', false);
		if (strlen(filter_input(INPUT_SERVER,'HTTP_COOKIE')))
		{
			$config = JFactory::getConfig();
			$cookies = explode(';', filter_input(INPUT_SERVER,'HTTP_COOKIE'));
			$params = $this->sysParams();
			$cookiedomains = (array)$params->get('cookiedomains', array());
			foreach ($cookies as $cookie)
			{
				if(strlen(trim($cookie))) {
					$this->killCookie($cookie, $cookiedomains, $config);
				}
			}
		}	
		return true;
	}

	// really private methods have no underscore
	private function sysParams() {
		$plugin = JPluginHelper::getPlugin('system','eprivacy');
		$params = new JRegistry($plugin->params);
		return $params;
	}
	
	private function killCookie($cookie,$cookiedomains,$config) {
		$parts = explode('=', $cookie);
		$name = trim($parts[0]);
		$this->input->cookie->set($name, '', time() - 86400);
		$this->input->cookie->set($name, '', -time() - 86400, $config->get('cookie_path','/'), $config->get('cookie_domain',filter_input(INPUT_SERVER,'HTTP_HOST')));
		if(count($cookiedomains)) {
			foreach($cookiedomains as $o) {
				$this->input->cookie->set($name, '', time() - 86400, $config->get('cookie_path','/'),$o->domain);
			}
		}		
	}
}
